# py-img-gen lib

[![CI](https://github.com/py-img-gen/py-img-gen-lib/actions/workflows/ci.yaml/badge.svg)](https://github.com/py-img-gen/py-img-gen-lib/actions/workflows/ci.yaml)

A library for the book "Image Generation with Python".
